================
Getting Started
================

Overview
---------

Free Unified Rendering for Python


What is Fury ?
---------------



Mission Statement
------------------

The purpose of FURY is to make it easier to do better diffusion MR imaging research. Following up with the nipy mission statement we aim to build software that is

* clearly written
* clearly explained
* a good fit for the underlying ideas
* a natural home for collaboration

We hope that, if we fail to do this, you will let us know and we will try and make it better.

Features
---------

**Efficient**



**Robust**


**Multiplatform**


License
---------

FURY is distributed under the BSD 3 License

Credits
--------

The following people have been involved in the development of FURY:

* Eleftherios Garyfallidis, Indiana University, IN, USA
* Marc-Alexandre Côté, Microsoft Research, Montreal, QC, CA
* David Reagan, Indiana University, IN, USA
* Ranveer Aggarwal, Microsoft, Hyderabad, Telangana, India
* Serge Koudoro, Indiana University, IN, USA
* Karandeep Singh Juneja, India

Bug reports and support
---------------------------

Please report any issues via https://github.com/fury-gl/fury/issues. All types of issues are welcome including bug reports, documentation typos, feature requests and so on.

